#
# spec file for package Coin
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           Coin
Version:        3.1.3
Release:        7.10
License:        GPL-2.0
Summary:        Multiplatform high-level 3D graphics library
Url:            http://www.coin3d.org/lib/coin/
Group:          Development/Libraries/C and C++
Source0:        http://ftp.coin3d.org/coin/src/all/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gcc-4.7.patch asterios.dramis@gmail.com -- Fix compilation with gcc-4.7 (based on a Fedora patch)
Patch0:         gcc-4.7.patch
# PATCH-FIX-UPSTREAM gcc-4.8.patch johannesobermayr@gmx.de -- Fix compilation with gcc-4.8
Patch1:         gcc-4.8.patch
BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The core rendering library Coin is a multiplatform high-level 3D graphics
library with a C++ API. Coin uses OpenGL for accelerated rendering, while
providing a higher abstraction level, 3D interactivity, and many complex
optimization features for fast rendering that are transparent for the
application programmer, thus facilitating the development of interactive 3D
applications and greatly increasing productivity.

%package devel
Summary:        Development files for Coin
Group:          Development/Libraries/C and C++
Requires:       libCoin60 = %{version}
Requires:       fontconfig-devel
Requires:       freetype2-devel
Requires:       openal-soft-devel
Requires:       pkgconfig(bzip2)
Requires:       pkgconfig(dri)
Requires:       pkgconfig(ice)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xt)
Requires:       zlib-devel

%description devel
The core rendering library Coin is a multiplatform high-level 3D graphics
library with a C++ API. Coin uses OpenGL for accelerated rendering, while
providing a higher abstraction level, 3D interactivity, and many complex
optimization features for fast rendering that are transparent for the
application programmer, thus facilitating the development of interactive 3D
applications and greatly increasing productivity.

%package -n libCoin60
Summary:        Multiplatform high-level 3D graphics library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libCoin60
The core rendering library Coin is a multiplatform high-level 3D graphics
library with a C++ API. Coin uses OpenGL for accelerated rendering, while
providing a higher abstraction level, 3D interactivity, and many complex
optimization features for fast rendering that are transparent for the
application programmer, thus facilitating the development of interactive 3D
applications and greatly increasing productivity.

%prep
%setup -q
%patch0
%patch1 -p1

# Remove build time references so build-compare can do its work
sed -i "s/Generated on \$datetime/Generated/" docs/doxygen/footer.html

# freetype.h is now in #_includedir/freetype2
# https://build.opensuse.org/request/show/210110
# To avoid confusion of the three freetype.h files the dir is mandatory
%if 0%{?suse_version} > 1310
sed -i "s:<freetype/:<freetype2/:g" src/glue/freetype.h
sed -i "s:<freetype/:<freetype2/:g" src/glue/freetype.cpp
%endif

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%configure \
    --htmldir=%{_docdir}/%{name}-devel/html \
    --enable-3ds-import \
    --enable-javascript-api \
    --enable-threadsafe \
    --enable-html \
    --enable-man \
    --disable-dl-openal \
    --disable-dl-fontconfig \
    --disable-dl-freetype \
    --disable-dl-zlib \
    --disable-dl-libbzip2 \
    --disable-dl-glu \
    --with-freetype=%{_prefix}

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

# Fix rpmlint warning "pkgconfig-invalid-libs-dir". -L${libdir} is already included in the Coin.pc file
sed -i "s/\-L\/usr\/lib64 \-L\/usr\/lib/ /" %{buildroot}%{_libdir}/pkgconfig/Coin.pc

# Fix the libdir
sed -i -e "s,\-L/usr/lib64 \-L/usr/lib,\-L%{_libdir}," %{buildroot}%{_datadir}/Coin/conf/coin-default.cfg

# Remove unneeded files
rm -f %{buildroot}%{_libdir}/*.la

# Install additional documentation
install -pm 0644 AUTHORS COPYING ChangeLog FAQ FAQ.legal LICENSE.GPL NEWS README RELNOTES THANKS \
 %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}%{_docdir}/%{name}-devel/

%post -n libCoin60 -p /sbin/ldconfig

%postun -n libCoin60 -p /sbin/ldconfig

%files -n libCoin60
%defattr(-,root,root,-)
%doc LICENSE.GPL
%{_datadir}/Coin/
%{_libdir}/libCoin.so.60*

%files devel
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-devel/
%{_bindir}/coin-config
%{_includedir}/Inventor/
%{_includedir}/SoDebug.h
%{_includedir}/SoWinEnterScope.h
%{_includedir}/SoWinLeaveScope.h
%{_libdir}/pkgconfig/Coin.pc
%{_libdir}/libCoin.so
%{_datadir}/aclocal/coin.m4
%doc %{_mandir}/man1/coin-config.1%{ext_man}
%doc %{_mandir}/man3/*.3%{ext_man}

%changelog
* Fri Jan  3 2014 johannesobermayr@gmx.de
- Fix build on openSUSE > 13.1
* Sat Nov 30 2013 johannesobermayr@gmx.de
- Fix compile on gcc 4.8 (gcc-4.8.patch).
* Sun Oct 28 2012 asterios.dramis@gmail.com
- Added bzip2 as build requirement (needed for Factory).
* Tue Sep 25 2012 asterios.dramis@gmail.com
- Use pkgconfig(...) for Mesa and xorg-x11 build requirements. This fixes also
  compilation in Factory due to the Mesa package changes (with the addition of
  pkgconfig(dri) as build requirement).
* Sat Apr 28 2012 asterios.dramis@gmail.com
- Added the following devel packages as requirements of Coin-devel:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
* Fri Apr 27 2012 asterios.dramis@gmail.com
- Added a patch to fix compilation with gcc-4.7 (based on a patch from Fedora).
- Link to the needed libraries during compilation instead of using runtime
  linking. This added the following build dependencies:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
- Removed freeglut-devel dependency (not needed).
- Build development documentation (with doxygen).
- Changed License to GPL-2.0.
- Remove build time references so build-compare can do its work.
- Use the correct arch libdir in Coin.pc and coin-default.cfg files.
* Fri Dec 10 2010 andrea@links2linux.de
- new upstream version 3.1.3
* Sat Sep 26 2009 Andrea Florio <andrea@links2linux.de> 3.1.1
- new upstream version
* Sun Sep 28 2008 Andrea Florio <andrea@links2linux.de>
- complete spec rewrite
* Sun Nov 18 2007 Michal Vyskocil <mvyskocil@suse.cz>
- First release for OpenSuse Build Service
